@@ -1,6 +1,6 @@
 import pandas as pd
 from .seeker import Seeker
-from sql_engine import SQLEngine
+from .sql_engine import SQLEngine
 
 def extract_from_src(content_size):
     """ > gets raw data from site, assigns new useragent
